@@ -65,7 +65,7 @@ const char *_mutt_fmt_pgp_command (char *dest,
 				   const char *prefix,
 				   const char *ifstring,
 				   const char *elsestring,
-				   unsigned long data,
+				   void *data,
 				   format_flag flags)
 {
   char fmt[16];
@@ -150,7 +150,7 @@ const char *_mutt_fmt_pgp_command (char *dest,
 
 void mutt_pgp_command (char *d, size_t dlen, struct pgp_command_context *cctx, const char *fmt)
 {
-  mutt_FormatString (d, dlen, 0, MuttIndexWindow->cols, NONULL (fmt), _mutt_fmt_pgp_command, (unsigned long) cctx, 0);
+  mutt_FormatString (d, dlen, 0, MuttIndexWindow->cols, NONULL (fmt), _mutt_fmt_pgp_command, cctx, 0);
   dprint (2, (debugfile, "mutt_pgp_command: %s\n", d));
 }
 
